# aiolang/language/langs_text.py
class LangsText:
    SUPPORTED_LANGUAGES = {
        "aa": "Afar",
        "ab": "Abkhazian",
        "af": "Afrikaans",
        "sq": "Albanian",
        "am": "Amharic",
        "ar": "Arabic",
        "hy": "Armenian",
        "as": "Assamese",
        "ay": "Aymara",
        "az": "Azerbaijani",
        "ba": "Bashkir",
        "eu": "Basque",
        "be": "Belarusian",
        "bn": "Bengali",
        "bs": "Bosnian",
        "br": "Breton",
        "bg": "Bulgarian",
        "my": "Burmese",
        "km": "Cambodian",
        "ca": "Catalan",
        "zh": "Chinese",
        "co": "Corsican",
        "hr": "Croatian",
        "cs": "Czech",
        "da": "Danish",
        "nl": "Dutch",
        "en": "English",
        "eo": "Esperanto",
        "et": "Estonian",
        "fo": "Faeroese",
        "fj": "Fiji",
        "fi": "Finnish",
        "fr": "French",
        "fy": "Frisian",
        "gl": "Galician",
        "ka": "Georgian",
        "de": "German",
        "el": "Greek",
        "kl": "Greenlandic",
        "gn": "Guarani",
        "gu": "Gujarati",
        "ha": "Hausa",
        "haw": "Hawaiian",
        "he": "Hebrew",
        "hi": "Hindi",
        "hu": "Hungarian",
        "is": "Icelandic",
        "id": "Indonesian",
        "ia": "Interlingua",
        "ie": "Interlingue",
        "ik": "Inupiak",
        "iu": "Inuktitut",
        "ga": "Irish",
        "it": "Italian",
        "ja": "Japanese",
        "jw": "Javanese",
        "kn": "Kannada",
        "ks": "Kashmiri",
        "kk": "Kazakh",
        "km": "Khmer",
        "rw": "Kinyarwanda",
        "ky": "Kirghiz",
        "rn": "Kirundi",
        "ko": "Korean",
        "ku": "Kurdish",
        "lo": "Laothian",
        "la": "Latin",
        "lv": "Latvian",
        "ln": "Lingala",
        "lt": "Lithuanian",
        "mk": "Macedonian",
        "mg": "Malagasy",
        "ms": "Malay",
        "ml": "Malayalam",
        "mt": "Maltese",
        "mi": "Maori",
        "mr": "Marathi",
        "mo": "Moldavian",
        "mn": "Mongolian",
        "na": "Nauru",
        "ne": "Nepali",
        "no": "Norwegian",
        "oc": "Occitan",
        "or": "Oriya",
        "ps": "Pashto",
        "fa": "Persian",
        "pl": "Polish",
        "pt": "Portuguese",
        "pa": "Punjabi",
        "qu": "Quechua",
        "rm": "Rhaeto-Romance",
        "ro": "Romanian",
        "ru": "Russian",
        "sm": "Samoan",
        "sg": "Sangro",
        "sa": "Sanskrit",
        "gd": "Scots Gaelic",
        "sr": "Serbian",
        "sh": "Serbo-Croatian",
        "st": "Sesotho",
        "tn": "Setswana",
        "sn": "Shona",
        "sd": "Sindhi",
        "si": "Singhalese",
        "ss": "Siswati",
        "sk": "Slovak",
        "sl": "Slovenian",
        "so": "Somali",
        "es": "Spanish",
        "su": "Sudanese",
        "sw": "Swahili",
        "sv": "Swedish",
        "tl": "Tagalog",
        "tg": "Tajik",
        "ta": "Tamil",
        "tt": "Tatar",
        "te": "Tegulu",
        "th": "Thai",
        "bo": "Tibetan",
        "ti": "Tigrinya",
        "to": "Tonga",
        "ts": "Tsonga",
        "tr": "Turkish",
        "tk": "Turkmen",
        "tw": "Twi",
        "ug": "Uighur",
        "uk": "Ukrainian",
        "ur": "Urdu",
        "uz": "Uzbek",
        "vi": "Vietnamese",
        "vo": "Volapuk",
        "cy": "Welch",
        "wo": "Wolof",
        "xh": "Xhosa",
        "yi": "Yiddish",
        "yo": "Yoruba",
        "za": "Zhuang",
        "zu": "Zulu"
    }